# ramp-core
Welcome to the core utilities package of the nuclear Reactor Analysis
Management Project!

## Core utilities of RAMP

This is where we handle serialization, pickling and such things that are used everywhere in the wide project.

This package does almost nothing on its own, and one would usually only
interact with it as a dependency.
More often than not, people reading this will find other packages more
useful, but you're welcome to contribute here too if you came all this
way :)

